@@ -2,12 +2,15 @@ package POD2::ES;
 use warnings;
 use strict;
 
-use utf8;
 use base 'POD2::Base';
 
-our $VERSION = '5.12.3.02';
+our $VERSION = '5.12.3.03';
 
-my $pods = {
+sub search_perlfunc_re {
+    return 'Lista de funciones de Perl en orden alfabtico';
+}
+
+sub pod_info {{
     perlintro   => '5.12.3',
     perl        => '5.12.3',
     perlbook    => '5.12.3',
@@ -17,28 +20,26 @@ my $pods = {
     # perlfunc   => '5.12.3',
     # perlstyle  => '5.12.3',
     # perlsyn    => '5.12.3',
-};
-
+}};
 
 sub print_pod {
+    my $self = shift;
     my @args = @_ ? @_ : @ARGV;
 
+    my $pods = $self->pod_info;
     while (@args) {
         (my $pod = lc(shift @args)) =~ s/\.pod$//;
         if ( exists $pods->{$pod} ) {
             print "\t'$pod' traducido correspondiente a Perl $pods->{$pod}\n";
-        } else {
-            print "\t'$pod' no existe\n";
+        }
+        else {
+            print "\t'$pod' todava no existe\n";
         }
     }
 }
 
-
-sub search_perlfunc_re {
-    return 'Lista de funciones de Perl en orden alfabtico';
-}
-
 1;
+
 __END__
 
 =head1 NOMBRE
@@ -58,13 +59,13 @@ POD2::ES - Documentacin de Perl en espaol
 
 =head1 DESCRIPCIN
 
-pod2es es el proyecto de traduccin al espaol de la documentacin bsica
-de Perl. Por su dimensin, es un proyecto a largo plazo.   
+pod2es es el proyecto de traduccin al espaol de la documentacin bsica de
+Perl. Por su dimensin, es un proyecto a largo plazo.
 
-Vea L<http://github.com/zipf/perldoc-es> para obtener ms informacin. 
+Vea L<http://github.com/zipf/perldoc-es> para obtener ms informacin.
 
 Cuando haya instalado el paquete, puede utilizar el siguiente comando para
-consultar la documentacin: 
+consultar la documentacin:
 
   %> perldoc POD2::ES::<nombre_de_pod>
 
@@ -73,16 +74,16 @@ consultar la documentacin:
 Por desgracia, los tiles modificadores C<-f> y C<-q> de C<perldoc> no
 funcionan con la documentacin traducida.
 
-Por esta razn, hemos creado una revisin de F<Pod/Perldoc.pm> 3.14 que
-permite utilizar la siguiente sintaxis: 
+Por esta razn, a partir de la versin 3.14 de Pod::Perldoc se permite utilizar
+la siguiente sintaxis:
 
   %> perldoc -L ES <nombre_pod>
   %> perldoc -L ES -f <funcin>
   %> perldoc -L ES -q <expresin regular P+F>
 
-La revisin agrega el modificador C<-L>, que permite definir el cdigo de
-idioma para la traduccin deseada. Si el paquete C<POD2::E<lt>idiomaE<gt>>
-no existe, no se aplicar el modificador.
+El modificador C<-L> permite definir el cdigo de idioma para la traduccin
+deseada. Si el paquete C<POD2::E<lt>idiomaE<gt>> no existe, no se aplicar el
+modificador.
 
 Los ms perezosos pueden agregar un alias del sistema:
 
@@ -92,24 +93,25 @@ para no tener que escribir el modificador C<-L> cada vez:
 
   %> perldoc-es -f map 
  
-Puede aplicar la revisin con la lnea siguiente: 
+Con la versin 3.15 de Pod::Perldoc se puede usar la variable de entorno
+PERLDOC_POD2. Si se establece esta variable en '1', perldoc buscar en la
+documentacin pod segn el idioma indicado en las variables LC_ALL, LC_LANG o
+LANG. O bien, se puede establecer en el valor 'es', con lo que buscar
+directamente en la documentacin en espaol. Por ejemplo:
 
-  %> patch -p0 `/ruta_de_perl -MPod::Perldoc -e 'print $INC{"Pod/Perldoc.pm"}'` < /ruta/Perldoc.pm-3.14-patch
+       export PERLDOC_POD2="es"
+       perldoc perl
 
-La revisin se incluye con esta distribucin y se encuentra en
-F<./patches/Perldoc.pm-3.14-patch>.
 
 Tenga en cuenta que la revisin es para la versin 3.14 de
-L<Pod::Perldoc|Pod::Perldoc>
-(incluida en Perl 5.8.7 y en Perl 5.8.8). Si tiene una distribucin de Perl
-anterior
-(salvo la E<gt>= 5.8.1) y est impaciente por aplicar la revisin,
-actualice el mdulo L<Pod::Perldoc|Pod::Perldoc> a la versin 3.14.   
+L<Pod::Perldoc|Pod::Perldoc> (incluida en Perl 5.8.7 y en Perl 5.8.8). Si tiene
+una distribucin de Perl anterior (salvo la E<gt>= 5.8.1) y est impaciente por
+aplicar la revisin, actualice el mdulo L<Pod::Perldoc|Pod::Perldoc> a la
+versin 3.14.    Perl 5.10 ya contiene esta funcionalidad, por lo que no es
+necesario aplicar la revisin.
 
 Consulte la API C<search_perlfunc_re> para obtener ms informacin.
 
-I<Nota: Perl 5.10 ya contiene esta funcionalidad, por lo que no es
-necesario aplicar la revisin.>
 
 =head1 API
 
@@ -120,8 +122,7 @@ El paquete exporta las siguientes funciones:
 =item * C<new>
 
 Se ha agregado por compatibilidad con la funcin C<perldoc> de Perl 5.10.1.
-L<Pod::Perldoc> la utiliza para devolver el nombre del paquete de
-traduccin.
+L<Pod::Perldoc> la utiliza para devolver el nombre del paquete de traduccin.
 
 =item * C<pod_dirs>
 
@@ -141,20 +142,19 @@ pods pasados como argumentos.
 
 =item * C<search_perlfunc_re>
 
-Como el mtodo C<search_perlfunc> de F<Pod/Perldoc.pm> utiliza la cadena
-"Lista de funciones de Perl en orden alfabtico" incluida en el cdigo
-(como una expresin regular) para omitir la introduccin, a fin de que el
-archivo de revisin funcione con otros idiomas con la opcin C<-L>, hemos
-utilizado un mecanismo sencillo, similar a un complemento. 
+Como el mtodo C<search_perlfunc> de F<Pod/Perldoc.pm> utiliza la cadena "Lista
+de funciones de Perl en orden alfabtico" incluida en el cdigo (como una
+expresin regular) para omitir la introduccin, a fin de que el archivo de
+revisin funcione con otros idiomas con la opcin C<-L>, hemos utilizado un
+mecanismo sencillo, similar a un complemento.
 
 El paquete de idioma C<POD2::E<lt>idiomaE<gt>> debe exportar
-C<search_perlfunc_re> para devolver una traduccin de la cadena mencionada
-en el prrafo anterior. Esta cadena se usar para omitir la introduccin de
-F<perlfunc.pod>. Si 
-C<POD2::E<lt>idiomaE<gt>-E<gt>search_perlfunc_re> genera un error (o no
-existe), se restablece el comportamiento predeterminado. Este mecanismo
-permite agregar traducciones de C<POD2::*> adicionales sin necesidad de
-aplicar cada vez la revisin de F<Pod/Perldoc.pm>.
+C<search_perlfunc_re> para devolver una traduccin de la cadena mencionada en
+el prrafo anterior. Esta cadena se usar para omitir la introduccin de
+F<perlfunc.pod>. Si  C<POD2::E<lt>idiomaE<gt>-E<gt>search_perlfunc_re> genera
+un error (o no existe), se restablece el comportamiento predeterminado. Este
+mecanismo permite agregar traducciones de C<POD2::*> adicionales sin necesidad
+de aplicar cada vez la revisin de F<Pod/Perldoc.pm>.
 
 =back
 
@@ -167,9 +167,9 @@ L<http://github.com/zipf/perldoc-es>.
 
 =over
 
-=item * Joaqun Ferrero, C< explorer at joaquinferrero.com >
+=item * Joaqun Ferrero, C< explorer + POD2ES at joaquinferrero.com >
 
-=item * Enrique Nell, C< blas.gordon at gmail.com >
+=item * Enrique Nell, C< blas.gordon + POD2ES at gmail.com >
 
 =back
 
@@ -182,37 +182,37 @@ Para este proyecto hemos tomado las siguientes decisiones:
 =item * No utilizar caracteres acentuados en los nombres de variables y
 funciones de los ejemplos de cdigo
 
-Es perfectamente posible utilizarlos (solo hay que codificar el programa
-como UTF-8 y agregar "use utf8;" al principio), pero teniendo en mente a
-ese programador ms impulsivo, que valora su tiempo y no quiere perderse en
-reflexiones ni verse encorsetado por las normas de la lengua, creemos que
-as resultar ms fcil probar el cdigo de los ejemplos.
+Es perfectamente posible utilizarlos (solo hay que codificar el programa como
+UTF-8 y agregar "use utf8;" al principio), pero teniendo en mente a ese
+programador ms impulsivo, que valora su tiempo y no quiere perderse en
+reflexiones ni verse encorsetado por las normas de la lengua, creemos que as
+resultar ms fcil probar el cdigo de los ejemplos.
 
 Por otra parte, en aquellos sistemas que cuenten con un sistema antiguo de
 visualizacin de texto, como los terminales de lnea de comandos, es posible
-que se pierdan los acentos. En la mayor parte de los casos ser debido
-a la presencia de una versin de groff (programa utilizado por los comandos
-man y perldoc) que no admite dichos caracteres. En la documentacin
-HTML no debera haber problemas.
+que se pierdan los acentos. En la mayor parte de los casos ser debido a la
+presencia de una versin de groff (programa utilizado por los comandos man y
+perldoc) que no admite dichos caracteres. En la documentacin HTML no debera
+haber problemas.
 
 
 =item * No traducir los trminos "array" y "hash"
 
-Si tenemos en cuenta que Perl tiene ms de 20 aos y que la inmensa mayora
-de los libros disponibles sobre este lenguaje estn en ingls, a nadie extraar
+Si tenemos en cuenta que Perl tiene ms de 20 aos y que la inmensa mayora de
+los libros disponibles sobre este lenguaje estn en ingls, a nadie extraar
 que la comunidad de habla hispana se refiera a estos tipos de datos por su
 nombre en ingls. Existen posibles traducciones, como "matriz", "lista" o
 "arreglo" para "array", o "diccionario" para "hash", pero su uso no se ha
-extendido, por lo que hemos preferido utilizar su nombre original.
-Creemos que esto facilitar la lectura de la documentacin.
+extendido, por lo que hemos preferido utilizar su nombre original. Creemos que
+esto facilitar la lectura de la documentacin.
 
 
 =item * Utilizar "espaol neutro"
 
 El "espaol neutro" es un espaol controlado que pretende evitar el uso de
 trminos ofensivos o de construcciones poco frecuentes en determinados pases
-de habla hispana, con el objetivo de lograr traducciones vlidas para 
-Espaa y Latinoamrica.
+de habla hispana, con el objetivo de lograr traducciones vlidas para  Espaa y
+Latinoamrica.
 
 =back
 
@@ -225,13 +225,13 @@ L<POD2::PT_BR>, L<POD2::IT>, L<POD2::FR>, L<POD2::LT>, L<perl>.
 =head1 ERRORES
 
 Puede notificar errores (bugs) o solicitar funcionalidad a travs de la
-direccin de correo electrnico C<bug-pod2-esd at rt.cpan.org> o de la
-interfaz web en L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=POD2-ES>. 
-Se le comunicarn automticamente los cambios relacionados con los errores
+direccin de correo electrnico C<bug-pod2-esd at rt.cpan.org> o de la interfaz
+web en L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=POD2-ES>.  Se le
+comunicarn automticamente los cambios relacionados con los errores
 notificados o la funcionalidad solicitada.
 
 
-=head1 ASISTENCIA
+=head1 SOPORTE
 
 Para ver la documentacin de este mdulo, utilice el comando perldoc.
 
@@ -263,8 +263,8 @@ L<http://search.cpan.org/dist/POD2-ES/>
 
 =head1 AGRADECIMIENTOS
 
-Los autores desean expresar su gratitud al equipo de desarrollo
-de OmegaT, la herramienta utilizada para la traduccin.
+Los autores desean expresar su gratitud al equipo de desarrollo de OmegaT, la
+herramienta utilizada para la traduccin.
 
 
 =head1 REFERENCIAS
@@ -274,23 +274,22 @@ Proyecto OmegaT: L<http://omegat.org/>
 
 =head1 DONATIVOS
 
-Por el elevado volumen de trabajo que representa y su larga duracin,
-el proyecto de traduccin de la documentacin de Perl requiere un 
-esfuerzo sostenido que slo est al alcance de los espritus ms 
-slidos y altruistas.
-Los autores no exigen--pero tampoco rechazarn--compensaciones en 
-forma de dinero, libros, quesos y productos derivados del cerdo (o chancho),
-o incluso viajes a la Polinesia, destinadas a reducir la fatiga del
-equipo y a mantener alta la moral. Todo ser bienvenido.
+Por el elevado volumen de trabajo que representa y su larga duracin, el
+proyecto de traduccin de la documentacin de Perl requiere un  esfuerzo
+sostenido que slo est al alcance de los espritus ms  slidos y altruistas.
+Los autores no exigen--pero tampoco rechazarn--compensaciones en  forma de
+dinero, libros, quesos y productos derivados del cerdo (o chancho), o incluso
+viajes a la Polinesia, destinadas a reducir la fatiga del equipo y a mantener
+alta la moral. Todo ser bienvenido.
 
 
 =head1 LICENCIA Y COPYRIGHT
 
 Copyright 2011 Equipo de Perl en Espaol.
 
-Este programa es software libre; puede redistribuirlo o modificarlo bajo
-los trminos de la licencia GNU General Public License publicada por la
-Free Software Foundation, o los de la licencia Artistic.
+Este programa es software libre; puede redistribuirlo o modificarlo bajo los
+trminos de la licencia GNU General Public License publicada por la Free
+Software Foundation, o los de la licencia Artistic.
 
 Consulte http://dev.perl.org/licenses/ para obtener ms informacin.
 
